api.assets.v1.test_helpers.service package — Argus-Toolbelt 1.0 documentation

# api.assets.v1.test_helpers.service package

## Submodules

## api.assets.v1.test_helpers.service.add_service_asset module

`api.assets.v1.test_helpers.service.add_service_asset.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/service, respond with HTTP 403

`api.assets.v1.test_helpers.service.add_service_asset.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/service, respond with HTTP 404

`api.assets.v1.test_helpers.service.add_service_asset.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/service, respond with HTTP 200

`api.assets.v1.test_helpers.service.add_service_asset.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/service, respond with HTTP 401

## api.assets.v1.test_helpers.service.attach_hosts_to_service module

`api.assets.v1.test_helpers.service.attach_hosts_to_service.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/service/w+/attachhosts, respond with HTTP 403

`api.assets.v1.test_helpers.service.attach_hosts_to_service.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/service/w+/attachhosts, respond with HTTP 404

`api.assets.v1.test_helpers.service.attach_hosts_to_service.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/service/w+/attachhosts, respond with HTTP 200

`api.assets.v1.test_helpers.service.attach_hosts_to_service.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/service/w+/attachhosts, respond with HTTP 401

## api.assets.v1.test_helpers.service.delete_service_asset module

`api.assets.v1.test_helpers.service.delete_service_asset.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/service/w+, respond with HTTP 403

`api.assets.v1.test_helpers.service.delete_service_asset.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/service/w+, respond with HTTP 404

`api.assets.v1.test_helpers.service.delete_service_asset.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/service/w+, respond with HTTP 200

`api.assets.v1.test_helpers.service.delete_service_asset.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/service/w+, respond with HTTP 401

## api.assets.v1.test_helpers.service.detach_hosts_from_service module

`api.assets.v1.test_helpers.service.detach_hosts_from_service.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/service/w+/detachhosts, respond with HTTP 403

`api.assets.v1.test_helpers.service.detach_hosts_from_service.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/service/w+/detachhosts, respond with HTTP 404

`api.assets.v1.test_helpers.service.detach_hosts_from_service.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/service/w+/detachhosts, respond with HTTP 200

`api.assets.v1.test_helpers.service.detach_hosts_from_service.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/service/w+/detachhosts, respond with HTTP 401

## api.assets.v1.test_helpers.service.get_service_asset module

`api.assets.v1.test_helpers.service.get_service_asset.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/service/w+, respond with HTTP 403

`api.assets.v1.test_helpers.service.get_service_asset.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/service/w+, respond with HTTP 404

`api.assets.v1.test_helpers.service.get_service_asset.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/service/w+, respond with HTTP 200

`api.assets.v1.test_helpers.service.get_service_asset.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/service/w+, respond with HTTP 401

## api.assets.v1.test_helpers.service.search_service_asset_statistics module

`api.assets.v1.test_helpers.service.search_service_asset_statistics.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/service/statistics, respond with HTTP 403

`api.assets.v1.test_helpers.service.search_service_asset_statistics.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/service/statistics, respond with HTTP 404

`api.assets.v1.test_helpers.service.search_service_asset_statistics.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/service/statistics, respond with HTTP 200

`api.assets.v1.test_helpers.service.search_service_asset_statistics.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/service/statistics, respond with HTTP 401

## api.assets.v1.test_helpers.service.search_service_assets module

`api.assets.v1.test_helpers.service.search_service_assets.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/service/search, respond with HTTP 403

`api.assets.v1.test_helpers.service.search_service_assets.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/service/search, respond with HTTP 404

`api.assets.v1.test_helpers.service.search_service_assets.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/service/search, respond with HTTP 200

`api.assets.v1.test_helpers.service.search_service_assets.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/service/search, respond with HTTP 401

## api.assets.v1.test_helpers.service.search_service_assets_simplified module

`api.assets.v1.test_helpers.service.search_service_assets_simplified.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/service, respond with HTTP 403

`api.assets.v1.test_helpers.service.search_service_assets_simplified.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/service, respond with HTTP 404

`api.assets.v1.test_helpers.service.search_service_assets_simplified.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/service, respond with HTTP 200

`api.assets.v1.test_helpers.service.search_service_assets_simplified.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/service, respond with HTTP 401

## api.assets.v1.test_helpers.service.update_service_asset module

`api.assets.v1.test_helpers.service.update_service_asset.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/service/w+, respond with HTTP 403

`api.assets.v1.test_helpers.service.update_service_asset.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/service/w+, respond with HTTP 404

`api.assets.v1.test_helpers.service.update_service_asset.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/service/w+, respond with HTTP 200

`api.assets.v1.test_helpers.service.update_service_asset.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/assets/v1/service/w+, respond with HTTP 401

## Module contents